@@ -1,5 +1,5 @@
 package Plack::Handler::Stomp;
-$Plack::Handler::Stomp::VERSION = '1.12';
+$Plack::Handler::Stomp::VERSION = '1.13';
 {
   $Plack::Handler::Stomp::DIST = 'Plack-Handler-Stomp';
 }
@@ -310,7 +310,7 @@ sub build_psgi_env {
         # http
         HTTP_USER_AGENT => 'Net::Stomp',
         CONTENT_LENGTH => length($frame->body),
-        CONTENT_TYPE => $frame->headers->{'content-type'},
+        CONTENT_TYPE => ( $frame->headers->{'content-type'} || 'application/octet-stream' ),
 
         # psgi
         'psgi.version' => [1,0],
@@ -355,7 +355,7 @@ Plack::Handler::Stomp - adapt STOMP to (almost) HTTP, via Plack
 
 =head1 VERSION
 
-version 1.12
+version 1.13
 
 =head1 SYNOPSIS
 
